@@ -45,12 +45,14 @@ def check_virtualenv(path):
 
 
 def install_virtualenv(install_path=""):
-    output = subprocess.check_call(["virtualenv", "-p", "/usr/local/bin/python2.7", install_path])
+    cmd = ["virtualenv", "-p", "/usr/local/bin/python2.7", virtualenv_path]
+    print cmd
+    output = subprocess.check_call(cmd)
     print output
 
 
 def install_pip(name, install_path="", virtualenv=True, upgrade=False):
-    cmd = os.path.join(install_path, "env", "bin") if virtualenv else install_path
+    cmd = os.path.join(install_path, virtualenv_path, "bin") if virtualenv else install_path
     cmd = os.path.join(cmd, "pip")
     name = name.split(" ")
     cmd = [cmd, "install"]
