@@ -1,3 +1,4 @@
+uwsgi
 -r https://raw.githubusercontent.com/mapbox/rasterio/master/requirements.txt
 rasterio
 GeobricksCommon
@@ -6,4 +7,5 @@ GeobricksGISRaster
 GeobricksSpatialQuery
 GeobricksDistribution
 GeobricksGeostatistics
-GeobricksGeocoding
\ No newline at end of file
+GeobricksGeocoding
+GeobricksRESTEngine
\ No newline at end of file
